﻿Option Strict On
Imports Coding4Fun.Kinect.Wpf
Imports System.Windows.Media.Imaging
Imports MultiTouch.Behaviors.WPF4
Imports CursorClass.KinectCursor
Imports Microsoft.Kinect


Class MainWindow
    Dim behavior As MultiTouchBehavior
    Dim myImage As Image
    Dim no As Integer = 10
    Dim newSensor As KinectSensor

    Const SkeletonMaxX As Single = 0.6F
    Const SkeletonMaxY As Single = 0.4F
    Const ClickThreshold As Single = 0.33F
    Dim xmldoc As XElement
    Dim _image As Image
    Private Sub MainWindow_Loaded(sender As Object, e As System.Windows.RoutedEventArgs) Handles Me.Loaded
        xmldoc = XElement.Load("photo_etc.xml")
        For Each result In From c In xmldoc.Descendants("画像名") Select c
            myImage = New Image
            behavior = New MultiTouchBehavior
            With myImage
                .Width = 320
                .Height = 240
                .Source = New BitmapImage(New Uri("Image/" & result.Value, UriKind.Relative))
            End With

            ImageShowArea.Children.Add(myImage)

            AddHandler myImage.MouseLeftButtonDown, Sub(mouseSender As Object, mouseArgs As MouseButtonEventArgs)
                                                        _image = DirectCast(mouseArgs.Source, Image)
                                                        no = no + 1
                                                        _image.SetValue(Canvas.ZIndexProperty, no)

                                                    End Sub

            behavior.Attach(myImage)

        Next
        AddHandler KinectSensorChooser1.KinectSensorChanged, Sub(kinectSender As Object, kinectArgs As DependencyPropertyChangedEventArgs)
                                                                 Dim oldSensor As KinectSensor = DirectCast(kinectArgs.OldValue, KinectSensor)
                                                                 StopKinect(oldSensor)
                                                                 newSensor = DirectCast(kinectArgs.NewValue, KinectSensor)
                                                                 If newSensor Is Nothing = True Then
                                                                     Return
                                                                 End If

                                                                 Dim myParam As New TransformSmoothParameters
                                                                 With myParam
                                                                     .Smoothing = 0.7F
                                                                     .Correction = 0.3F
                                                                     .Prediction = 0.4F
                                                                     .JitterRadius = 1.0F
                                                                     .MaxDeviationRadius = 0.5F
                                                                 End With


                                                                 With newSensor
                                                                     .SkeletonStream.Enable(myParam)
                                                                     .ColorStream.Enable(ColorImageFormat.RgbResolution640x480Fps30)
                                                                 End With


                                                                 AddHandler newSensor.AllFramesReady, Sub(frameSender As Object, frameArgs As AllFramesReadyEventArgs)
                                                                                                          SensorSkeletonReady(frameArgs)
                                                                                                          SensorColorFrameReady(frameArgs)

                                                                                                      End Sub

                                                                 Try
                                                                     newSensor.Start()
                                                                 Catch ex As Exception
                                                                     MessageBox.Show(ex.Message)
                                                                     Exit Sub
                                                                 End Try

                                                             End Sub

    End Sub



    Private Sub SensorSkeletonReady(e As AllFramesReadyEventArgs)
        Using skeletonFrameData As SkeletonFrame = e.OpenSkeletonFrame
            If skeletonFrameData Is Nothing = True Then
                Return
            End If

            Dim skeletonArray(skeletonFrameData.SkeletonArrayLength - 1) As Skeleton

            skeletonFrameData.CopySkeletonDataTo(skeletonArray)
            For Each skeletonData In skeletonArray

                If skeletonData.TrackingState = SkeletonTrackingState.Tracked Then

                    If skeletonData.Joints(JointType.HandLeft).TrackingState = JointTrackingState.Tracked AndAlso skeletonData.Joints(JointType.HandRight).TrackingState = JointTrackingState.Tracked Then
                        Dim cursorX As Integer
                        Dim cursorY As Integer

                        Dim jointRight As Joint = skeletonData.Joints(JointType.HandRight)
                        Dim jointLeft As Joint = skeletonData.Joints(JointType.HandLeft)

                        Dim scaledRight As Joint = jointRight.ScaleTo(CInt(Fix(SystemParameters.PrimaryScreenWidth)), CInt(Fix(SystemParameters.PrimaryScreenHeight)), SkeletonMaxX, SkeletonMaxY)
                        Dim scaledLeft As Joint = jointLeft.ScaleTo(CInt(Fix(SystemParameters.PrimaryScreenWidth)), CInt(Fix(SystemParameters.PrimaryScreenHeight)), SkeletonMaxX, SkeletonMaxY)

                        cursorX = CInt(Fix(scaledRight.Position.X))
                        cursorY = CInt(Fix(scaledRight.Position.Y))

                        Dim leftClick As Boolean
                        If jointRight.Position.Y > ClickThreshold OrElse (Not jointLeft.Position.Y > ClickThreshold) Then
                            leftClick = True
                        Else
                            leftClick = False
                        End If
                        'SendMouseInputの書式SendMouseInput(ByVal positionX As Integer, ByVal positionY As Integer, ByVal maxX As Integer, ByVal maxY As Integer, ByVal leftDown As Boolean)
                        KinectCursor.SendMouseInput(cursorX, cursorY, CInt(Fix(SystemParameters.PrimaryScreenWidth)), CInt(Fix(SystemParameters.PrimaryScreenHeight)), leftClick)

                        Return
                    End If
                End If
            Next
        End Using
    End Sub

    Private Sub SensorColorFrameReady(e As AllFramesReadyEventArgs)

        Using colorFrame As ColorImageFrame = e.OpenColorImageFrame
            If colorFrame Is Nothing = True Then
                Return
            End If
            Image1.Source = colorFrame.ToBitmapSource
        End Using

    End Sub

    Private Sub StopKinect(ByVal sensor As KinectSensor)
        If sensor Is Nothing = False Then
            If sensor.IsRunning = True Then
                sensor.Stop()
                sensor.Dispose()
            End If
        End If
    End Sub

  

    Private Sub MainWindow_Closing(sender As Object, e As System.ComponentModel.CancelEventArgs) Handles Me.Closing
        StopKinect(newSensor)
    End Sub

 
End Class
